@@ -29,12 +29,12 @@ class iterable_storage(Storage):
         for value in values:
             if isinstance(value, str):
                 types.add('string')
+            elif isinstance(value, bool):
+                types.add('boolean')
             elif isinstance(value, int):
                 types.add('integer')
             elif isinstance(value, (float, decimal.Decimal)):
                 types.add('number')
-            elif isinstance(value, bool):
-                types.add('boolean')
             elif isinstance(value, list):
                 types.add('array')
             elif isinstance(value, dict):
@@ -47,7 +47,7 @@ class iterable_storage(Storage):
                 pass
             else:
                 assert 'Unknown Python type: %r' % value
-        if len(types) > 1:
+        if len(types) != 1:
             return 'any'
         else:
             return types.pop()
@@ -88,7 +88,7 @@ class iterable_loader(DataStreamProcessor):
         try:
             for x in self.iterable:
                 if mode is None:
-                    assert isinstance(x, (dict, list)), 'Bad item %r' % x
+                    assert isinstance(x, (dict, list, tuple)), 'Bad item %r' % x
                     mode = dict if isinstance(x, dict) else list
                 assert isinstance(x, mode)
                 if mode == dict:
